==> knative-model-4.12.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSourceListBuilder extends KafkaSourceListFluentImpl<KafkaSourceListBuilder> implements VisitableBuilder<KafkaSourceList,KafkaSourceListBuilder> {

    KafkaSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaSourceListBuilder() { 
        this(true);
    }


    public KafkaSourceListBuilder(Boolean validationEnabled) { 
        this(new KafkaSourceList(), validationEnabled);
    }


    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent) { 
        this(fluent, true);
    }


    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new KafkaSourceList(), validationEnabled);
    }


    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,KafkaSourceList instance) { 
        this(fluent, instance, true);
    }


    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,KafkaSourceList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaSourceListBuilder(KafkaSourceList instance) { 
        this(instance,true);
    }


    public KafkaSourceListBuilder(KafkaSourceList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public KafkaSourceList build() {
        KafkaSourceList buildable = new KafkaSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaSourceListBuilder that = (KafkaSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaSourceListBuilder.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class KafkaSourceListBuilder extends KafkaSourceListFluentImpl<KafkaSourceListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<KafkaSourceList,KafkaSourceListBuilder> {

    KafkaSourceListFluent<?> fluent;
    Boolean validationEnabled;

    public KafkaSourceListBuilder() {
        this(true);
    }

    public KafkaSourceListBuilder(Boolean validationEnabled) {
        this(new KafkaSourceList(), validationEnabled);
    }

    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent) {
        this(fluent, true);
    }

    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new KafkaSourceList(), validationEnabled);
    }

    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,KafkaSourceList instance) {
        this(fluent, instance, true);
    }

    public KafkaSourceListBuilder(KafkaSourceListFluent<?> fluent,KafkaSourceList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public KafkaSourceListBuilder(KafkaSourceList instance) {
        this(instance,true);
    }

    public KafkaSourceListBuilder(KafkaSourceList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.eventing.contrib.kafka.v1beta1.EditableKafkaSourceList build() {
        EditableKafkaSourceList buildable = new EditableKafkaSourceList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        KafkaSourceListBuilder that = (KafkaSourceListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
